<template>
  <AppHead :title="data.title" />
  <div class="container page-container">
    <PageTitle :title="data.title">
      <Link class="btn btn-sm btn-light" :href="route('admin.applicants.index')">
        <i class="fas fa-users"></i>
        {{ __("View Applicants") }}</Link
      >
    </PageTitle>

    <div class="row">
      <div class="col-md-12">
        <Table
          :options="tableOptions"
          :links="applicants.links"
          :total="applicants.total"
        >
          <template v-slot>
            <tr v-for="(applicant, index) in applicants.data" :key="index">
              <td>
                <Link :href="route('admin.applicants.show', applicant.uuid)">{{
                  applicant.number
                }}</Link>
              </td>
              <td class="">
                {{ localDate(applicant.created_at) }}
              </td>
              <td class="">
                {{ applicant.first_name }} {{ applicant.last_name }}
                <div class="text-muted">{{ applicant.email }}</div>
              </td>
              <td class="text-center">
                <DestroyButton
                  :delete_url="route('admin.applicants.destroy', applicant.uuid)"
                />
              </td>
            </tr>
          </template>
        </Table>
      </div>
    </div>
  </div>
</template>

<script>
import Table from "../../../components/Table.vue";
import DestroyButton from "../../../components/Form/DestroyButton.vue";

export default {
  props: ["data", "applicants"],
  components: {
    Table,
    DestroyButton,
  },
  data() {
    return {
      tableOptions: {
        titles: [
          {
            name: this.__("Number"),
            className: "",
          },
          {
            name: this.__("Created At"),
            className: "",
          },
          {
            name: this.__("Name"),
            className: "",
          },
          {
            name: null,
            className: "text-center",
          },
        ],
      },
    };
  },
};
</script>
